==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/en_GB.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activity",
    "Personal activity feed for %s" : "Personal activity feed for %s",
    "Your feed URL is invalid" : "Your feed URL is invalid",
    "Your settings have been updated." : "Your settings have been updated.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "This stream will show events like additions, changes & shares" : "This stream will show events like additions, changes & shares",
    "There are no events for this filter" : "There are no events for this filter",
    "Activity notification" : "Activity notification",
    "All Activities" : "All Activities",
    "Activities by you" : "Activities by you",
    "Activities by others" : "Activities by others",
    "\"remote user\"" : "\"remote user\"",
    "in %s" : "in %s",
    "%s and %s" : "%s and %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s and %n more","%s and %n more"],
    "Hello %s," : "Hello %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* and %n more ","* and %n more "],
    "Notifications" : "Notifications",
    "List your own actions in the stream" : "List your own actions in the stream",
    "Notify about your own actions via email" : "Notify about your own actions via email",
    "You need to set up your email address before you can receive notification emails." : "You need to set up your email address before you can receive notification emails.",
    "Send emails:" : "Send emails:",
    "Hourly" : "Hourly",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "Activity feed" : "Activity feed",
    "Enable RSS feed" : "Enable RSS feed",
    "No activity yet" : "No activity yet",
    "No more events to load" : "No more events to load",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/en_GB.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activity",
    "Activities" : "Activities",
    "Error loading activities" : "Error loading activities",
    "No activities" : "No activities",
    "Load more activities" : "Load more activities",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} and {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} and {linkStart}%n more{linkEnd}","{parameterList} and {linkStart}%n more{linkEnd}"],
    "in {directory}" : "in {directory}",
    "This stream will show events like additions, changes & shares" : "This stream will show events like additions, changes & shares",
    "There are no events for this filter" : "There are no events for this filter",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "Personal activity feed for %s" : "Personal activity feed for %s",
    "Your feed URL is invalid" : "Your feed URL is invalid",
    "Your settings have been updated." : "Your settings have been updated.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "\"remote user\"" : "\"remote user\"",
    "Activity notification" : "Activity notification",
    "All Activities" : "All Activities",
    "Activities by you" : "Activities by you",
    "Activities by others" : "Activities by others",
    "%s and %s" : "%s and %s",
    "Hello %s," : "Hello %s,",
    "You are receiving this email because the following things happened at %s" : "You are receiving this email because the following things happened at %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* and %n more ","* and %n more "],
    "List your own file actions in the stream" : "List your own file actions in the stream",
    "Notify about your own actions via email" : "Notify about your own actions via email",
    "You need to set up your email address before you can receive notification emails." : "You need to set up your email address before you can receive notification emails.",
    "Send emails:" : "Send emails:",
    "Hourly" : "Hourly",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "Activity feed" : "Activity feed",
    "Enable RSS feed" : "Enable RSS feed",
    "No activity yet" : "No activity yet",
    "No more events to load" : "No more events to load",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");
